==> zio-aws-globalaccelerator_2.13-5.17.158.1-sources.jar: zio/aws/globalaccelerator/model/DeprovisionByoipCidrResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeprovisionByoipCidrResponse(
    byoipCidr: Option[zio.aws.globalaccelerator.model.ByoipCidr] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse = {
    import DeprovisionByoipCidrResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse
      .builder()
      .optionallyWith(byoipCidr.map(value => value.buildAwsValue()))(
        _.byoipCidr
      )
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse.ReadOnly =
    zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse
      .wrap(buildAwsValue())
}
object DeprovisionByoipCidrResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse =
      zio.aws.globalaccelerator.model
        .DeprovisionByoipCidrResponse(byoipCidr.map(value => value.asEditable))
    def byoipCidr: Option[zio.aws.globalaccelerator.model.ByoipCidr.ReadOnly]
    def getByoipCidr: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.ByoipCidr.ReadOnly
    ] = AwsError.unwrapOptionField("byoipCidr", byoipCidr)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse
  ) extends zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse.ReadOnly {
    override val byoipCidr
        : Option[zio.aws.globalaccelerator.model.ByoipCidr.ReadOnly] = scala
      .Option(impl.byoipCidr())
      .map(value => zio.aws.globalaccelerator.model.ByoipCidr.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse
  ): zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-5.17.190.1-sources.jar: zio/aws/globalaccelerator/model/DeprovisionByoipCidrResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeprovisionByoipCidrResponse(
    byoipCidr: Optional[zio.aws.globalaccelerator.model.ByoipCidr] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse = {
    import DeprovisionByoipCidrResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse
      .builder()
      .optionallyWith(byoipCidr.map(value => value.buildAwsValue()))(
        _.byoipCidr
      )
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse.ReadOnly =
    zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse
      .wrap(buildAwsValue())
}
object DeprovisionByoipCidrResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse =
      zio.aws.globalaccelerator.model
        .DeprovisionByoipCidrResponse(byoipCidr.map(value => value.asEditable))
    def byoipCidr: Optional[zio.aws.globalaccelerator.model.ByoipCidr.ReadOnly]
    def getByoipCidr: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.ByoipCidr.ReadOnly
    ] = AwsError.unwrapOptionField("byoipCidr", byoipCidr)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse
  ) extends zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse.ReadOnly {
    override val byoipCidr
        : Optional[zio.aws.globalaccelerator.model.ByoipCidr.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.byoipCidr())
        .map(value => zio.aws.globalaccelerator.model.ByoipCidr.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DeprovisionByoipCidrResponse
  ): zio.aws.globalaccelerator.model.DeprovisionByoipCidrResponse.ReadOnly =
    new Wrapper(impl)
}
